%%%
%% pLaTeX2e Class File for Japanese Journal of Applied Statistics
%%   by ULS & Company (2001-2020), E-mail: teppei@uls.co.jp
\NeedsTeXFormat{pLaTeX2e}
\ProvidesClass{jjas}
%%[2005/09/02 v1.0 for Japanese Journal of Applied Statistics]
%%[2011/02/17 v1.1 for Japanese Journal of Applied Statistics]
  [2020/08/07 v2.0 for Japanese Journal of Applied Statistics]

\newif\if@enable@uptex \@enable@uptexfalse
\ifx\ucs\@undefined\else
 \ifnum\ucs"3000="3000
  \@enable@uptextrue
 \fi
\fi

\newdimen\@JQ
\if@enable@uptex
 \@JQ=0.769362pt % 1/0.924714=1.08141544 | 0.71144 x 1.08141544 = 0.769362pt 
\else
 \@JQ=0.7392507pt
\fi
%\newdimen\@Q
% \@Q=0.71144pt
\newdimen\@EM
 \@EM=.03125em

\def\jjas@warning{\ClassWarningNoLine{jjas}}

\newif\if@english \@englishfalse
\DeclareOption{english}{\@englishtrue}

\newif\if@Proof \@Prooffalse
\DeclareOption{Proof}{\@Prooftrue}
\newif\if@cameraready \@camerareadyfalse
\DeclareOption{cameraready}{\@camerareadytrue}

\newcounter{@paper}
\newcommand{\@ptsize}{}
\newif\if@restonecol
\hour\time \divide\hour by 60\relax
\@tempcnta\hour \multiply\@tempcnta 60\relax
\minute\time \advance\minute-\@tempcnta
\newif\if@stysize \@stysizefalse
\newif\if@enablejfam \@enablejfamtrue
\newif\if@mathrmmc \@mathrmmcfalse
\DeclareOption{b5paper}{\setcounter{@paper}{4}%
  \setlength\paperheight {257mm}
  \setlength\paperwidth  {182mm}}
\DeclareOption{b5j}{\setcounter{@paper}{4}% \@stysizetrue
  \setlength\paperheight {257mm}
  \setlength\paperwidth  {182mm}}
\DeclareOption{10pt}{\renewcommand{\@ptsize}{0}}
\DeclareOption{11pt}{\renewcommand{\@ptsize}{1}}
\DeclareOption{12pt}{\renewcommand{\@ptsize}{2}}
\DeclareOption{tombow}{%
  \tombowtrue \tombowdatetrue
  \setlength{\@tombowwidth}{.1\p@}%
  \@bannertoken{%
     \jobname\space:\space\number\year/\number\month/\number\day
      (\number\hour:\number\minute)}
  \maketombowbox}
\DeclareOption{tombo}{%
  \tombowtrue \tombowdatefalse
  \setlength{\@tombowwidth}{.1\p@}%
  \maketombowbox}
\DeclareOption{mentuke}{%
  \tombowtrue
  \setlength{\@tombowwidth}{\z@}%
  \@bannertoken{}% \@empty
  \maketombowbox}
\DeclareOption{tate}{\AtBeginDocument{\tate\message{scg[ht}}}
\DeclareOption{oneside}{\@twosidefalse}
\DeclareOption{twoside}{\@twosidetrue}
\DeclareOption{onecolumn}{\@twocolumnfalse}
\DeclareOption{twocolumn}{\@twocolumntrue}
%%\DeclareOption{leqno}{\input{leqno.clo}}
%%\DeclareOption{fleqn}{\input{fleqn.clo}}
\DeclareOption{openbib}{%
  \AtEndOfPackage{%
   \renewcommand\@openbib@code{%
      \advance\leftmargin\bibindent
      \itemindent -\bibindent
      \listparindent \itemindent
      \parsep \z@
      }%
   \renewcommand\newblock{\par}}}
\DeclareOption{disablejfam}{\@enablejfamfalse}
\DeclareOption{draft}{\setlength\overfullrule{5pt}}
\DeclareOption{final}{\setlength\overfullrule{0pt}}
\ExecuteOptions{b5paper,10pt,twoside,onecolumn,final}
\ProcessOptions\relax

%% pdf papersize
\iftombow % +26mm (10+3)x2
 \AtBeginDvi{\special{papersize=208mm,283mm}}%
 \hoffset-12.425mm\voffset-12.425mm % 13?
\else
 \AtBeginDvi{\special{papersize=182mm,257mm}}%
\fi

\def\kenc@JYn{\if@enable@uptex JY2\else JY1\fi}
\def\kenc@JTn{\if@enable@uptex JT2\else JT1\fi}

\if@enable@uptex
\if@cameraready
 \input jjas-utf.fd
\else
\DeclareFontShape{JY2}{mc}{m}{n}{%
  <5>     s*[0.995848]upjisr-h %  7Q
  <7>     s*[1.016171]upjisr-h % 10Q
  <8>     s*[0.978065]upjisr-h % 11Q
  <9>     s*[0.948427]upjisr-h % 12Q
  <10>    s*[0.924714]upjisr-h % 13Q
  <10.95> s*[0.974411]upjisr-h % 15Q
  <12>    s*[1.06698]upjisr-h  % 18Q
  <14.4>  s*[0.987944]upjisr-h % 20Q
  <17.28> s*[0.987944]upjisr-h % 24Q
  <20.74> s*[0.960316]upjisr-h % 28Q
  %<24.88> s*[0.914881]upjisr-h % 32Q
  <-> s*[0.924714]upjisr-h
}{}
\DeclareFontShape{JY2}{gt}{m}{n}{%
  <5>     s*[0.995848]upjisg-h %  7Q
  <7>     s*[1.016171]upjisg-h % 10Q
  <8>     s*[0.978065]upjisg-h % 11Q
  <9>     s*[0.948427]upjisg-h % 12Q
  <10>    s*[0.924714]upjisg-h % 13Q
  <10.95> s*[0.974411]upjisg-h % 15Q
  <12>    s*[1.06698]upjisg-h  % 18Q
  <14.4>  s*[0.987944]upjisg-h % 20Q
  <17.28> s*[0.987944]upjisg-h % 24Q
  <20.74> s*[0.960316]upjisg-h % 28Q
  %<24.88> s*[0.914881]upjisg-h % 32Q
  <->s*[0.924714]upjisg-h
}{}
%%
\DeclareFontShape{JT2}{mc}{m}{n}{%
  <5>     s*[0.995848]upjisr-v %  7Q
  <7>     s*[1.016171]upjisr-v % 10Q
  <8>     s*[0.978065]upjisr-v % 11Q
  <9>     s*[0.948427]upjisr-v % 12Q
  <10>    s*[0.924714]upjisr-v % 13Q
  <10.95> s*[0.974411]upjisr-v % 15Q
  <12>    s*[1.06698]upjisr-v  % 18Q
  <14.4>  s*[0.987944]upjisr-v % 20Q
  <17.28> s*[0.987944]upjisr-v % 24Q
  <20.74> s*[0.960316]upjisr-v % 28Q
  %<24.88> s*[0.914881]upjisr-v % 32Q
  <-> s*[0.924714]upjisr-v
}{}
\DeclareFontShape{JT2}{gt}{m}{n}{%
  <5>     s*[0.995848]upjisg-v %  7Q
  <7>     s*[1.016171]upjisg-v % 10Q
  <8>     s*[0.978065]upjisg-v % 11Q
  <9>     s*[0.948427]upjisg-v % 12Q
  <10>    s*[0.924714]upjisg-v % 13Q
  <10.95> s*[0.974411]upjisg-v % 15Q
  <12>    s*[1.06698]upjisg-v  % 18Q
  <14.4>  s*[0.987944]upjisg-v % 20Q
  <17.28> s*[0.987944]upjisg-v % 24Q
  <20.74> s*[0.960316]upjisg-v % 28Q
  %<24.88> s*[0.914881]upjisg-v % 32Q
  <->s*[0.924714]upjisg-v
}{}
\fi
\else
\if@cameraready
 \input jjas.fd
\else
\DeclareFontShape{JY1}{mc}{m}{n}{%
  <5>     sfixed * [5.1748] jis %  7Q
  <6>     sfixed * [5.9141] jis %  8Q
  <7>     sfixed * [7.3926] jis % 10Q
  <8>     sfixed * [8.1318] jis % 11Q
  <9>     sfixed * [8.8711] jis % 12Q
  <10>    sfixed * [9.6104] jis % 13Q
  <10.95> sfixed * [11.089] jis % 15Q
  <12>    sfixed * [13.307] jis % 18Q
  <14.4>  sfixed * [14.785] jis % 20Q
  <17.28> sfixed * [17.742] jis % 24Q
  <20.74> sfixed * [20.699] jis % 28Q
  <24.88> sfixed * [23.656] jis % 32Q
  <->                       jis % 
}{}
\DeclareFontShape{JY1}{gt}{m}{n}{%
  <5>     sfixed * [5.1748] jisg
  <6>     sfixed * [5.9141] jisg
  <7>     sfixed * [7.3926] jisg
  <8>     sfixed * [8.1318] jisg
  <9>     sfixed * [8.8711] jisg
  <10>    sfixed * [9.6104] jisg
  <10.95> sfixed * [11.089] jisg
  <12>    sfixed * [13.307] jisg
  <14.4>  sfixed * [14.785] jisg
  <17.28> sfixed * [17.742] jisg
  <20.74> sfixed * [20.699] jisg
  <24.88> sfixed * [23.656] jisg
  <->                       jisg
}{}
%%
\DeclareFontShape{JT1}{mc}{m}{n}{%
  <5>     sfixed * [5.1748] jis-v %  7Q
  <6>     sfixed * [5.9141] jis-v %  8Q
  <7>     sfixed * [7.3926] jis-v % 10Q
  <8>     sfixed * [8.1318] jis-v % 11Q
  <9>     sfixed * [8.8711] jis-v % 12Q
  <10>    sfixed * [9.6104] jis-v % 13Q
  <10.95> sfixed * [11.089] jis-v % 15Q
  <12>    sfixed * [13.307] jis-v % 18Q
  <14.4>  sfixed * [14.785] jis-v % 20Q
  <17.28> sfixed * [17.742] jis-v % 24Q
  <20.74> sfixed * [20.699] jis-v % 28Q
  <24.88> sfixed * [23.656] jis-v % 32Q
  <->                       jis-v % 
}{}
\DeclareFontShape{JT1}{gt}{m}{n}{%
  <5>     sfixed * [5.1748] jisg-v
  <6>     sfixed * [5.9141] jisg-v
  <7>     sfixed * [7.3926] jisg-v
  <8>     sfixed * [8.1318] jisg-v
  <9>     sfixed * [8.8711] jisg-v
  <10>    sfixed * [9.6104] jisg-v
  <10.95> sfixed * [11.089] jisg-v
  <12>    sfixed * [13.307] jisg-v
  <14.4>  sfixed * [14.785] jisg-v
  <17.28> sfixed * [17.742] jisg-v
  <20.74> sfixed * [20.699] jisg-v
  <24.88> sfixed * [23.656] jisg-v
  <->                       jisg-v
}{}
\fi
\fi

\DeclareFontShape{\kenc@JYn}{mc}{bx}{it}{<->ssub*gt/m/n}{}
\DeclareFontShape{\kenc@JYn}{mc}{bx}{n}{<->ssub*gt/m/n}{}
\DeclareFontShape{\kenc@JYn}{mc}{m}{it}{<->ssub*mc/m/n}{}
\DeclareFontShape{\kenc@JYn}{mc}{m}{sl}{<->ssub*mc/m/n}{}
\DeclareFontShape{\kenc@JYn}{gt}{bx}{it}{<->ssub*gt/m/n}{}
\DeclareFontShape{\kenc@JYn}{gt}{bx}{n}{<->ssub*gt/m/n}{}
\DeclareFontShape{\kenc@JYn}{gt}{m}{it}{<->ssub*gt/m/n}{}
\DeclareFontShape{\kenc@JYn}{gt}{m}{sl}{<->ssub*gt/m/n}{}
%%
\DeclareFontShape{\kenc@JTn}{mc}{bx}{it}{<->ssub*gt/m/n}{}
\DeclareFontShape{\kenc@JTn}{mc}{bx}{n}{<->ssub*gt/m/n}{}
\DeclareFontShape{\kenc@JTn}{mc}{m}{it}{<->ssub*mc/m/n}{}
\DeclareFontShape{\kenc@JTn}{mc}{m}{sl}{<->ssub*mc/m/n}{}
\DeclareFontShape{\kenc@JTn}{gt}{bx}{it}{<->ssub*gt/m/n}{}
\DeclareFontShape{\kenc@JTn}{gt}{bx}{n}{<->ssub*gt/m/n}{}
\DeclareFontShape{\kenc@JTn}{gt}{m}{it}{<->ssub*gt/m/n}{}
\DeclareFontShape{\kenc@JTn}{gt}{m}{sl}{<->ssub*gt/m/n}{}

\def\@setfontsize#1#2#3{\@nomath#1%
 \ifx\protect\@typeset@protect
   \let\@currsize#1%
 \fi
 \fontsize{#2}{#3}\selectfont
 \kanjiskip=0zw \@plus .1zw \@minus .025zw
 \xkanjiskip=0.25em \@plus 0.15em \@minus 0.06em
}

%% otf.sty \Cjascale (texlive 2018ȍ~)
\if@enable@uptex % for 10pt \normalsize
 \def\Cjascale{0.924714}% JY2
\else
 \def\Cjascale{0.96104}% JY1
\fi

\renewcommand{\normalsize}{%
    \@setfontsize\normalsize\@xpt{21H}%
  \abovedisplayskip 10\p@ \@plus2\p@ \@minus5\p@
  \abovedisplayshortskip \z@ \@plus3\p@
  \belowdisplayshortskip 6\p@ \@plus3\p@ \@minus3\p@
   \belowdisplayskip \abovedisplayskip
   \let\@listi\@listI}
\normalsize
\setbox0\hbox{\char\euc"A1A1}% "
\setlength\Cht{\ht0}
\setlength\Cdp{\dp0}
\setlength\Cwd{\wd0}
\setlength\Cvs{\baselineskip}
\setlength\Chs{\wd0}

\newcommand{\small}{%
  \@setfontsize\small\@ixpt{18H}%
  \abovedisplayskip 8.5\p@ \@plus3\p@ \@minus4\p@
  \abovedisplayshortskip \z@ \@plus2\p@
  \belowdisplayshortskip 4\p@ \@plus2\p@ \@minus2\p@
  \def\@listi{\leftmargin\leftmargini
              \topsep 4\p@ \@plus2\p@ \@minus2\p@
              \parsep 2\p@ \@plus\p@ \@minus\p@
              \itemsep \parsep}%
  \belowdisplayskip \abovedisplayskip}

\newcommand{\footnotesize}{%
  \@setfontsize\footnotesize\@viiipt{13H}%
  \abovedisplayskip 6\p@ \@plus2\p@ \@minus4\p@
  \abovedisplayshortskip \z@ \@plus\p@
  \belowdisplayshortskip 3\p@ \@plus\p@ \@minus2\p@
  \def\@listi{\leftmargin\leftmargini
              \topsep 3\p@ \@plus\p@ \@minus\p@
              \parsep 2\p@ \@plus\p@ \@minus\p@
              \itemsep \parsep}%
  \belowdisplayskip \abovedisplayskip}

\newcommand{\scriptsize}{\@setfontsize\scriptsize\@viipt\@viiipt}
\newcommand{\tiny}{\@setfontsize\tiny\@vpt\@vipt}
\newcommand{\large}{\@setfontsize\large\@xiipt{22H}}% subtitle/Eauthor
\newcommand{\Large}{\@setfontsize\Large\@xivpt{28H}}% title
\newcommand{\LARGE}{\@setfontsize\LARGE\@xviipt{25}}% ڎ
\newcommand{\huge}{\@setfontsize\huge\@xxpt{40H}}% title
\newcommand{\Huge}{\@setfontsize\Huge\@xxvpt{33}}

\headheight 12H %% 11Q
\headsep 5mm
\topskip 1\Cht
\footskip 7mm
\maxdepth .5\topskip
\textwidth 139.75mm %% 13Qx43w
%\@settopoint\textwidth
\textheight 39\Cvs
\advance \textheight \topskip
\if@enable@uptex
 \advance \textheight .15mm
\else
 \advance \textheight .35mm %% limit .34mm
\fi
%\@settopoint\textheight
\if@twocolumn
  \setlength\marginparsep{10\p@}
\else
  \setlength\marginparsep{10\p@}
\fi
\setlength\marginparpush{5\p@}

%\iftombow
 \topmargin\paperheight
 \advance \topmargin -\textheight
 \advance \topmargin -\headheight
 \advance \topmargin -\headsep
 \advance \topmargin -\footskip
 \divide \topmargin \tw@
 \advance \topmargin -2mm
 \advance \topmargin -1in
 %\@settopoint\topmargin
 \oddsidemargin\paperwidth
 \advance \oddsidemargin -\textwidth
 \divide \oddsidemargin \tw@
 \advance \oddsidemargin -1in
 %\@settopoint\oddsidemargin
 \evensidemargin\oddsidemargin
 %\@settopoint\evensidemargin
%\fi

\marginparwidth 2in
%\@settopoint\marginparwidth

\footnotesep 2.275mm
\skip\footins .75\Cvs \@plus 4\p@ \@minus 2\p@
\floatsep 1\Cvs \@plus 2\p@ \@minus 2\p@
\textfloatsep 1.5\Cvs \@plus 2\p@ \@minus 4\p@
\intextsep 1.5\Cvs \@plus 2\p@ \@minus 2\p@
\dblfloatsep 1\Cvs \@plus 2\p@ \@minus 2\p@
\dbltextfloatsep 1.5\Cvs \@plus 2\p@ \@minus 4\p@

\@fptop 0\p@ \@plus 1fil
\@fpsep 8\p@ \@plus 2fil
\@fpbot 0\p@ \@plus 1fil
\@dblfptop 0\p@ \@plus 1fil
\@dblfpsep 8\p@ \@plus 2fil
\@dblfpbot 0\p@ \@plus 1fil
\partopsep \z@

\def\@listi{\leftmargin\leftmargini
  \parsep  4\p@ \@plus2\p@ \@minus\p@
  \topsep  8\p@ \@plus2\p@ \@minus4\p@
  \itemsep 4\p@ \@plus2\p@ \@minus\p@}
\let\@listI\@listi
\@listi
\def\@listii{\leftmargin\leftmarginii
   \labelwidth\leftmarginii \advance\labelwidth-\labelsep
   \topsep 4\p@ \@plus2\p@ \@minus\p@
   \parsep 2\p@ \@plus\p@  \@minus\p@
   \itemsep\parsep}
\def\@listiii{\leftmargin\leftmarginiii
   \labelwidth\leftmarginiii \advance\labelwidth-\labelsep
   \topsep    2\p@  \@plus\p@\@minus\p@
   \parsep    \z@
   \partopsep \p@ \@plus\z@ \@minus\p@
   \itemsep\topsep}
\def\@listiv {\leftmargin\leftmarginiv
              \labelwidth\leftmarginiv
              \advance\labelwidth-\labelsep}
\def\@listv  {\leftmargin\leftmarginv
              \labelwidth\leftmarginv
              \advance\labelwidth-\labelsep}
\def\@listvi {\leftmargin\leftmarginvi
              \labelwidth\leftmarginvi
              \advance\labelwidth-\labelsep}

\columnsep 2zw
\columnseprule 0\p@
\lineskip 1\p@ 
\normallineskip 1\p@
\renewcommand{\baselinestretch}{}
\parskip\z@
\parindent1zw

\@lowpenalty   51
\@medpenalty  151
\@highpenalty 301
\setcounter{topnumber}{5}
\setcounter{bottomnumber}{5}
\setcounter{totalnumber}{10}
\setcounter{dbltopnumber}{5}
\renewcommand{\topfraction}{.95}
\renewcommand{\bottomfraction}{.95}
\renewcommand{\textfraction}{.05}
\renewcommand{\floatpagefraction}{.05}
\renewcommand{\dbltopfraction}{.95}
\renewcommand{\dblfloatpagefraction}{.05}

\if@Proof
 \def\@Rtop{\rlap{\smash{\rule[-\headsep]{0.05mm}{10mm}%
  \rule[-\headsep]{10mm}{0.05mm}}}}
 \def\@Ltop{\llap{\smash{\rule[-\headsep]{10mm}{0.05mm}%
  \rule[-\headsep]{0.05mm}{10mm}}}}
 \def\@Rbot{\rlap{\smash{\raisebox{1\footskip}
  {\rule[-10mm]{0.05mm}{10mm}\rule{10mm}{0.05mm}}}}}
 \def\@Lbot{\llap{\smash{\raisebox{1\footskip}
  {\rule{10mm}{0.05mm}\rule[-10mm]{0.05mm}{10mm}}}}}
\else
 \let\@Rtop\relax\let\@Ltop\relax\let\@Rbot\relax\let\@Lbot\relax
\fi

\def\nombre@font{\sffamily\bfseries\fontsize{7.5}{\z@}\selectfont}
\def\header@font{\footnotesize}

\def\ps@empty{%
 \let\ps@jpl@in\ps@plain%
 \def\@oddhead{\@Ltop\hfill\@Rtop}%
 \def\@oddfoot{\@Lbot\hfill\@Rbot}%
 \let\@evenhead\@oddhead
 \let\@evenfoot\@oddfoot
 \let\@mkboth\@gobbletwo
 %\let\chaptermark\@gobble
 %\let\sectionmark\@gobble
 %\let\subsectionmark\@gobble
}
\def\ps@plain{%
 \let\@mkboth\@gobbletwo
 \let\ps@jpl@in\ps@plain
 \def\@oddhead{\@Ltop\hfil\@Rtop}%
 \let\@evenhead\@oddhead
 \def\@oddfoot{\@Lbot\hfil{\nombre@font \thepage}\hfil\@Rbot}%
 \let\@evenfoot\@oddfoot
}
\let\ps@jpl@in\ps@plain

%\def\ps@headnombre{\let\@mkboth\@gobbletwo
%    \let\ps@jpl@in\ps@headnombre
%  \def\@evenhead{\@Ltop\thepage\hfill\@Rtop}%
%  \def\@oddhead{\@Ltop\hfill\thepage\@Rtop}%
%  \def\@oddfoot{\@Lbot\hfill\@Rbot}%
%  \let\@evenfoot\@oddfoot
%}
%\def\ps@footnombre{\let\@mkboth\@gobbletwo
%    \let\ps@jpl@in\ps@footnombre
%  \def\@evenfoot{\@Lbot\thepage\hfill\@Rbot}%
%  \def\@oddfoot{\@Lbot\hfill\thepage\@Rbot}%
%  \def\@oddhead{\@Ltop\hfill\@Rtop}%
%  \let\@evenhead\@oddhead}

%\def\ps@headings{\let\ps@jpl@in\ps@headnombre
%  \def\@oddfoot{\@Lbot\hfill\@Rbot}%
%  \def\@evenfoot{\@Lbot\hfill\@Rbot}%
%  \def\@evenhead{\@Ltop\thepage\hfill\leftmark\@Rtop}%
%  \def\@oddhead{\@Ltop{\rightmark}\hfil\thepage\@Rtop}%
%  \let\@mkboth\markboth
%  \def\sectionmark##1{\markboth{%
%     \ifnum \c@secnumdepth >\z@ \thesection\hskip1zw\fi
%     ##1}{}}%
%  \def\subsectionmark##1{\markright{%
%     \ifnum \c@secnumdepth >\@ne \thesubsection\hskip1zw\fi
%     ##1}}%
%}

\if@english
 \def\oddhead@JASJ{Japanese J.\ Appl.\ Statist.\ \ignorespaces}
\else
 \def\oddhead@JASJ{pvw}
\fi

\def\ps@bothstyle{%
 \let\ps@jpl@in\ps@plain
 \def\@evenhead{\@Ltop\hfil
  {\header@font \header@title}\hfil
  \@Rtop}%
 \def\@oddhead{\@Ltop\hfil
  {\header@font \oddhead@JASJ Vol.\,\@Vol, No.\,\@No\ (\the\@Y@ar)}\hfil
  \@Rtop}%
 \def\@oddfoot{\@Lbot\hfil{\nombre@font \thepage}\hfil\@Rbot}%
 \let\@evenfoot\@oddfoot
 \let\@mkboth\markboth
 %\let\sectionmark\@gobble
 %\let\subsectionmark\@gobble
}

\def\ps@myheadings{\let\ps@jpl@in\ps@plain%
 \def\@oddfoot{\@Lbot\hfil{\nombre@font \thepage}\hfil\@Rbot}%
 \let\@evenfoot\@oddfoot
 \def\@oddhead{\@Ltop\hfil
  {\header@font pvwVol.\,\@Vol, No.\,\@No\ (\the\@Y@ar)}\hfil
  \@Rtop}%
 \def\@evenhead{\@Ltop\hfil
  {\header@font \leftmark}\hfil
  \@Rtop}%
 \let\@mkboth\@gobbletwo
 %\let\sectionmark\@gobble
 %\let\subsectionmark\@gobble
}

%\def\p@thanks#1{\footnotemark
% \protected@xdef\@thanks{\@thanks
%  \protect{\noindent$\m@th^\thefootnote$~#1\protect\par}}}

\newcount\@Y@ar \@Y@ar 1971\relax

\def\Vol#1{\gdef\@Vol{#1}%
 \ifx\@Vol\@empty \gdef\@Vol{49}\fi
 \ifnum\@Y@ar=1971\relax
  \advance \@Y@ar \@Vol\relax
 \else
  \@Y@ar2020\relax
 \fi
}
\def\@Vol{}
\def\No#1{\gdef\@No{#1}}
\def\@No{}

\def\title{\@dblarg{\d@title}}
\def\d@title[#1]#2{%
 \gdef\header@title{\def\\{\unskip}\inhibitglue #1\inhibitglue}%
 \gdef\@title{\leavevmode\inhibitglue #2\inhibitglue}%
}
\def\header@title{}
\def\@title{}

\def\subtitle#1{%
 \gdef\@subtitle{#1}%
}
\def\@subtitle{}

%% type uRgv̂Ƃ ǂ肵Ȃ --> OK?
\def\type#1{\def\@tempa{Rg}\def\@tempb{#1}%
 \ifx\@tempb\@tempa\global\jidorifalse\fi
 \gdef\@type{#1}}
\def\@type{}

\newcommand{\maketitle}{\par
 \begingroup
  \newpage
  \global\@topnum\z@
  \@maketitle
  \thispagestyle{plain}%
 \endgroup
 \setcounter{footnote}{0}%
}

%\if@cameraready
% \def\title@font{\usekanji{\kenc@JYn}{mc}{b}{n}\huge}% 28Q
%\else
\def\title@font{\normalfont\huge}% 28Q
%\fi
\def\subtitle@font{\large}% 12pt 18Q
\def\affiliate@font{\normalfont\small}
\def\author@font{\normalfont\fontsize{10.95}{\z@}\selectfont}% 15Q
%\def\etitle@font{}
%\def\esubtitle@font{}
%\def\eaffiliate@font{}
%\def\eauthor@font}

\newtoks\@authorlist
\newcount\@authorcnt
\newcount\total@nr

\def\authorlist#1{%
 \if@english\let\authorentry\Eauthorentry\fi
 \@authorlist={#1}\the\@authorlist
}

\def\@checkword#1{\@tempcnta\z@\@getword #1\end}
\def\@getword#1{\ifx#1\end \let\next\relax \else
 \global\advance\@tempcnta \@ne
 \ifnum \@tempcnta=\@ne \gdef\@Getword{#1}\else \fi
 \let\next=\@getword\fi \next}
\def\@Getword{}

\def\authorentry#1#2{\@ifnextchar[% ]
 {\@aeN{#1}{#2}}{\@ae{#1}{#2}}}

\newif\if@oneaffi\@oneaffitrue

\def\fmt@ae#1#2{%
 \advance \@authorcnt \@ne
 %% author's name in Japanese
 \def\@checkname{#1}%
 \setbox\@tempboxa\hbox{\spaceskip 100mm #1}%
 \ifdim \wd\@tempboxa < 100mm
  \jjas@warning{Author's name "#1" doesn't have a space}%
  \def\@tempx{#1}%
 \else
  \@checkword{#1}%
  \setbox\@tempboxa\hbox{\@Getword}%
  \ifdim \wd\@tempboxa=1zw
   \setbox\@tempboxb\hbox{#1}%
   \ifdim \wd\@tempboxb > 6.5zw
    \def\@tempx{\spaceskip1zw #1}%% 1.2b
   \else
    \def\@checkbox##1 ##2\@nil{%
     \global\setbox\@tempboxa\hbox{##1}\global\setbox\@tempboxb\hbox{##2}}%
    \edef\@tempcheck{\expandafter\@checkbox\@checkname\@nil}\@tempcheck
     \def\@tempy##1 ##2\@nil{\hbox{%
      \ifdim \wd\@tempboxa < 3zw
       \hbox to 3zw{\kanjiskip 1zw plus 1zw ##1\hss}%
      \else
       %\hbox to 3zw{##1\hss}%
       ##1% v2.0
      \fi
     \hskip 1zw
      \ifdim \wd\@tempboxb < 3zw
       \hbox to 3zw{\hss\kanjiskip 1zw plus 1zw ##2}%
      \else
       %\hbox to 3zw{\hss ##2}%
       ##2% v2.0
      \fi
     }}%
    \edef\@tempx{\expandafter\@tempy\@checkname\@nil}%
   \fi
  \else
   \def\@tempx{#1}%
  \fi
 \fi
 %% \LastPageinEnglish ̒ҏ1̏ꍇ tȂ̂
 %% 邩ǂŔ
 \ifx\@hold@affi\empty
  \hold@affi{#2}%
 \else
  \def\another@affi{#2}%
  \ifx\@hold@affi\another@affi\else
   \global\@oneaffifalse
  \fi
 \fi
 %%
}

\def\hold@affi#1{\gdef\@hold@affi{#1}}%
\def\@hold@affi{}

%% ݂̏Ȃ̒
\def\@ae#1#2{%
 \fmt@ae{#1}{#2}%
  \expandafter\protected@xdef
  \csname @Jauthorname\number\@authorcnt\endcsname{%
   \noexpand\affiliate@font #2
    & \noexpand\author@font\@tempx\protect\\}% also \cr is OK
 \global\total@nr\@authorcnt
}

%% ݂̏̒
\newcount\ae@n@cnt
\def\@aeN#1#2[#3]{%
 \fmt@ae{#1}{#2}%
 \advance \ae@n@cnt \@ne
  \expandafter\protected@xdef
  \csname @Jauthorname\number\@authorcnt\endcsname{%
   \noexpand\affiliate@font #2\unskip\inhibitglue
     \rlap{\kern\z@$^\@fnsymbol{\the\ae@n@cnt}$}
    & \noexpand\author@font\@tempx\protect\\}%
  \bgroup
   \renewcommand{\thefootnote}{\fnsymbol{footnote}}%
   \protect\footnotetext[\the\ae@n@cnt]{#3}%
  \egroup
 \global\total@nr\@authorcnt
}

\def\@tempname{}

\def\@outputJauthorlist{%
 \loop
  \ifnum \@authorcnt<\total@nr
   \advance \@authorcnt \@ne
   \protected@xdef\@tempname{\@tempname
    \csname @Jauthorname\number\@authorcnt\endcsname
   }%
 \repeat
 \@tempname
}

\def\@maketitle{%
 \@authorcnt\z@
 \setbox\@tempboxa\hbox{%
  \begin{minipage}{\textwidth}
   {\footnotesize\bfseries pvw\hskip1zw
     \raise.35mm\hbox{\footnotesize Vol.\,\@Vol, No.\,\@No\ (\the\@Y@ar), 
      \@ifundefined{r@jjas@last@page}{}{%
       \edef\get@firstpage{\expandafter\@secondoftwo\r@jjas@first@page}%
       \edef\get@lastpage{\expandafter\@secondoftwo\r@jjas@last@page}%
      }%
      \ifx\get@firstpage\get@lastpage
       \pageref{jjas@first@page}%
      \else
       \pageref{jjas@first@page}--\pageref{jjas@last@page}%
      \fi
     }%
   }\hfill
    \ifx\@type\empty
     \fboxrule\z@\fboxsep1.15mm
    \else
     \fboxrule.12mm\fboxsep1.15mm
    \fi
    \fbox{\small\bfseries
     \rule{0mm}{2.75mm}%
     \setbox0\hbox{\@type}%
     \hskip.25mm
     \ifdim \wd0<4.5zw
      \kintou{5zw}{\@type}%
     \else
      \@type
     \fi
     \hskip.25mm
    }\par
   \nointerlineskip
   \vskip11mm %  12mm
   \centering
   {\title@font \@title\par}%
   \ifx\@subtitle\empty\else
    \vskip4mm
    {\subtitle@font \ddash\@subtitle\ddash\par}%
    \nointerlineskip
   \fi
   \nointerlineskip
   \vskip6mm %  8mm
   \hfill
   %% 
   {\def\arraystretch{1.43}% 30H
    \tabcolsep\z@
    \expandafter\@temptokena\expandafter{\@outputJauthorlist}%
    \begin{tabular}{r@{\hskip15H}l}
     \the\@temptokena
     \noalign{\vskip -\arraystretch\dp\strutbox}%
    \end{tabular}\par
   }%
   \nointerlineskip
   \vskip10mm   %  10mm
   \ifvoid\@abstractbox\else
    \leavevmode\box\@abstractbox
   \fi
  \end{minipage}%
 }%
 %%
 \@tempdima \ht\@tempboxa
 \advance \@tempdima \dp\@tempboxa
 \divide \@tempdima \Cvs
 \@tempcnta=\@tempdima
 \advance \@tempcnta \@ne
 %%
 \newpage\null
 \boxmaxdepth\z@
 \lineskiplimit\z@
 \lineskip\z@
 \vbox to \@tempcnta\Cvs{%
  \vskip-2.5mm
  \box\@tempboxa
  \vss
 }%
 \nobreak
}

\newbox\@abstractbox
\def\abstract{%
 \global\setbox\@abstractbox\hbox\bgroup
  \small
  \begin{minipage}{37zw}
   \parindent1zw
   \noindent
   {\bfseries v\hskip1zw |}\hskip1zw
   \ignorespaces
}
\def\endabstract{%
   \inhibitglue
  \end{minipage}%
 \egroup
}

\def\LastPageinEnglish{%
 \clearpage
 \title{}%
 \subtitle{}%
 \total@nr\z@
 \setcounter{figure}{0}%
 \setcounter{table}{0}%
 \setcounter{equation}{0}%
 \thispagestyle{plain}%
 \let\authorentry\Eauthorentry
 \global\let\@maketitle\@makeEtitle
 \@authorcnt\z@
 %%
 \def\abstract{%
    \normalsize \baselineskip18H
    \parindent1zw
    \noindent
    \hfil{\bfseries Abstract}\par
    \vskip.5\baselineskip
    \ignorespaces
 }%
 \def\endabstract{\par}%
 %%
 \let\refereed\output@Erefereed
 \let\CorrespondingAuthor\E@CorrespondingAuthor
}

\def\keywords{%
 \setbox0\hbox{M}%
 \@tempdima \ht0
 \advance \@tempdima \dp0
 \@tempdimb\baselineskip
 \advance \@tempdimb -\@tempdima
 \vskip\@tempdimb
 \vskip.5\baselineskip
 \nointerlineskip
 \raggedright
 \normalsize \baselineskip18H
 \noindent
 \@hangfrom{\bfseries Key words:\ }%
 \ignorespaces
}

\def\endkeywords{\onelineskip}

\def\@makeEtitle{%
 %%
 \def\@fnsymbol##1{\ensuremath{\ifcase##1\or
   1\or 2\or 3\or 4\or 5\or 6\or *\or **\or ***\else\@ctrerr\fi}}%
 \@authorcnt\z@
 %%
 \newpage\null
 \boxmaxdepth\z@
 \lineskiplimit\z@
 \lineskip\z@
 \vbox{\parindent\z@
  \vskip-2.5mm
  \if@english
   {\footnotesize\bfseries Japanese J.\ Appl.\ Statist.\hskip1zw
     \raise.35mm\hbox{\footnotesize Vol.\,\@Vol, No.\,\@No\ (\the\@Y@ar), 
      \pageref{jjas@first@page}--\pageref{jjas@last@page}%
     }%
   }\hfill
    \ifx\@type\empty
     \fboxrule\z@\fboxsep1.15mm
    \else
     \fboxrule.12mm\fboxsep1.15mm
    \fi
    \fbox{\small\bfseries
     \rule{0mm}{2.75mm}%
     \setbox0\hbox{\@type}%
     \hskip.25mm
     \ifdim \wd0<4.5zw
      \kintou{5zw}{\@type}%
     \else
      \@type
     \fi
     \hskip.25mm
    }\par
   \nointerlineskip
   \vskip11mm %  12mm
  \else
   {\small
    Japanese J.\ Appl.\ Statist.\ 
    \@Vol\ (\@No)\ (\the\@Y@ar), 
    \pageref{jjas@first@page}--\pageref{jjas@last@page}
   }\par
   \vskip4mm
  \fi
   \centering
   {\Large\bfseries \@title\par}%
   \ifx\@subtitle\empty\else
    \vskip3mm
    {\subtitle@font \ddash\@subtitle\ddash\par}%
    \nointerlineskip
   \fi
   \nointerlineskip
   \vskip5mm
   %% 
   {\large\bfseries\centering
    \@outputEauthorlist\par
   }%
   \nointerlineskip
   \vskip5mm
   {\small \baselineskip16H
    \centering
    \@affiliate\par
   }%
  \vss
 }%
 \nobreak
 \vskip7mm
}

\newcount\@alcnt
%\newcount\total@alcnt

\def\Eauthorentry{\@ifstar{\p@Eauthorentry}{\@Eauthorentry}}

\def\@Eauthorentry#1#2{%
 \@tempcnta\z@
 \advance \@authorcnt \@ne
 \get@al{#2}%
 \fmt@an{#1}%
 \expandafter\protected@xdef\csname @authorname\number\@authorcnt\endcsname{%
  \@authorname\if@oneaffi\else\unskip\plural@affi\fi}%
 \global\total@nr=\@authorcnt
 \def\plural@affi{}%
}

\newif\if@p@Eae \@p@Eaefalse

\def\p@Eauthorentry#1#2{%
 \global\@p@Eaetrue
 \@tempcnta\z@
 \advance \@authorcnt \@ne
 \get@al{#2}%
 \fmt@an{#1}%
 \expandafter\protected@xdef\csname @authorname\number\@authorcnt\endcsname{%
  \@authorname
  \if@oneaffi
   \unskip${}^{*}$%
  \else
   \unskip\plural@affi\hskip-.1ex${}^{,*}$%
  \fi}%
 \global\total@nr=\@authorcnt
 \def\plural@affi{}%
}

%\def\get@al#1{%
% \@for\get@label:=#1\do{%
%  \@ifundefined{al@\get@label}%
%   {\def\@noaffi{none}\def\@tempaffi{#1}%
%    \ifx\@noaffi\@tempaffi\else
%     \global\advance \@alcnt \@ne\fi
%    \expandafter\xdef\csname al@\get@label\endcsname{\the\@alcnt}%
%    \advance \@tempcnta \@ne
%    \expandafter\xdef\csname al@\romannumeral\@tempcnta\endcsname{%
%     \get@label}%
%   }%
%   {\advance \@tempcnta \@ne
%    \expandafter\xdef\csname al@\romannumeral\@tempcnta\endcsname{%
%     \get@label}%
%   }%
% }%
%}
\def\get@al#1{%
 \def\@noaffi{none}\def\@tempaffi{#1}%
 \ifx\@noaffi\@tempaffi\else
  \@for\get@label:=#1\do{%
   \@ifundefined{al@\get@label}%
    {\global\advance \@alcnt \@ne
     \expandafter\xdef\csname al@\get@label\endcsname{\the\@alcnt}%
     %\advance \@tempcnta \@ne
     %\expandafter\xdef\csname al@\romannumeral\@tempcnta\endcsname{%
     % \get@label}%
    }%
    {%\advance \@tempcnta \@ne
     %\expandafter\xdef\csname al@\romannumeral\@tempcnta\endcsname{%
     % \get@label}%
    }%
    %%
    \advance \@tempcnta \@ne
    \protected@xdef\plural@affi{\plural@affi\penalty\@M
     \ifnum\@tempcnta=\@ne
      $^{\csname al@\get@label\endcsname}$%
     \else
      $^{,\csname al@\get@label\endcsname}$% \kern-.25ex
     \fi
    }%
  }%
 \fi
}
\def\plural@affi{}

\def\fmt@an#1{%
 \@temptokena{#1}%
 \setbox\@tempboxa\hbox{\spaceskip=100mm #1}%
 \ifdim \wd\@tempboxa < 100mm
  \jjas@warning{a space should be added between 1st and 2nd name: "#1"}%
 \else
  \def\name@form##1 ##2\@nil{\gdef\@tempan{##1 ##2}}% \uppercase{##2}
  \expandafter\name@form\the\@temptokena\@nil
  \expandafter\@temptokena\expandafter{\@tempan}%
 \fi
 \def\@authorname{\the\@temptokena}%
}

%\def\plural@affi#1{%
% \@ifundefined{al@#1}
%  {\expandafter\ifnum\expandafter\csname al@\al@i\endcsname\expandafter 
%     >\csname al@\al@ii\endcsname
%    $^{\csname al@\al@ii\endcsname,}$%
%    $^{\csname al@\al@i\endcsname}$%
%   \else
%    $^{\csname al@\al@i\endcsname,}$%
%    $^{\csname al@\al@ii\endcsname}$%
%   \fi
%  }%
%   {\expandafter\ifnum\csname al@#1\endcsname=\z@\else
%    $^{\csname al@#1\endcsname}$\fi}%
%}

%\def\plural@p@affi#1#2{%
% \@ifundefined{al@#1}% --> LabelA,LabelB,..
%  {%
%   \if@oneaffi\else
%    \expandafter\ifnum\expandafter\csname al@\al@i\endcsname\expandafter %%<
%      >\csname al@\al@ii\endcsname
%     $^{\csname al@\al@ii\endcsname,}$%
%     $^{\csname al@\al@i\endcsname,}$%
%    \else
%     $^{\csname al@\al@i\endcsname,}$%
%     $^{\csname al@\al@ii\endcsname,}$%
%    \fi
%   \fi
%   \ifnum\total@nr=\@ne\else %% pr10
%    $^{\noexpand\@fnsymbol{\csname p@al@#2\endcsname}}$%
%   \fi
%  }%
%  {%
%   \if@oneaffi
%   \else %% pr10
%    $^{\csname al@#1\endcsname,}$% ==> vol33no3/2.tex
%   \fi
%   \ifnum\total@nr=\@ne
%   \else %% pr10
%    $^{\noexpand\@fnsymbol{\csname p@al@#2\endcsname}}$%
%   \fi
%  }% 
%}

\newcount\chk@al@cnt

\def\affiliate[#1]#2{%
 \advance \chk@al@cnt \@ne
 \@ifundefined{al@#1}{%
  \expandafter\def\csname al@#1\endcsname{1}%
  \jjas@warning{Check the "#1" label, it does not correspond to
    ^^J\space\space any labels in \string\authorentry\space command}%
 }{}%
  \protected@xdef\@affiliate{\@affiliate
   \if@oneaffi\else
   $^{\csname al@#1\endcsname}$\ \fi
   #2\endgraf}%
}
\def\@affiliate{}

\newcount\totalnumberm@ne

\def\breakauthorline#1{%
 \@for\@breakauthor:=#1\do{%
  \expandafter\gdef\csname @breakauthorline\@breakauthor\endcsname{\\}%
 }%
  \@authorcnt=\z@
  \loop\ifnum\@authorcnt<\total@nr
   \advance \@authorcnt \@ne
    \@ifundefined{@breakauthorline\number\@authorcnt}%
     {\expandafter\gdef\csname @breakauthorline\number\@authorcnt\endcsname{%
      \relax}}
     {\relax}%
  \repeat
}

\def\@outputEauthorlist{%
  \@authorcnt\z@
  \totalnumberm@ne\total@nr \advance \totalnumberm@ne -\@ne
  \loop\ifnum\@authorcnt<\total@nr
   \advance \@authorcnt \@ne 
    \ifnum\@authorcnt < \totalnumberm@ne
     \mbox{\csname @authorname\number\@authorcnt\endcsname
     }\nobreak,
     \csname @breakauthorline\number\@authorcnt\endcsname
    \else
     \ifnum\@authorcnt=\total@nr
      \mbox{\csname @authorname\number\@authorcnt\endcsname
      }
      \csname @breakauthorline\number\@authorcnt\endcsname
     \else
      \ifnum\total@nr=\tw@
       \mbox{\csname @authorname\number\@authorcnt\endcsname
       }%
       \csname @breakauthorline\number\@authorcnt\endcsname
       \allowbreak\mbox{\bfseries \ and\ }\nobreak 
      \else
       \mbox{\csname @authorname\number\@authorcnt\endcsname
       }%
       \csname @breakauthorline\number\@authorcnt\endcsname
       \allowbreak\mbox{\bfseries\ and\ }\nobreak 
      \fi
     \fi
    \fi
  \repeat
}

\setcounter{secnumdepth}{3}
%%\newcounter{part}
\newcounter{section}
\newcounter{subsection}[section]
\newcounter{subsubsection}[subsection]
\newcounter{paragraph}[subsubsection]
\newcounter{subparagraph}[paragraph]
%%\renewcommand{\thepart}{\@Roman\c@part}
\renewcommand{\thesection}{\@arabic\c@section}
\renewcommand{\thesubsection}{\thesection.\@arabic\c@subsection}
\renewcommand{\thesubsubsection}{%
   \thesubsection.\@arabic\c@subsubsection}
\renewcommand{\theparagraph}{%
   \thesubsubsection.\@arabic\c@paragraph}
\renewcommand{\thesubparagraph}{%
   \theparagraph.\@arabic\c@subparagraph}

%%\newcommand{\part}{\par\addvspace{4ex}%
%%  \@afterindentfalse
%%  \secdef\@part\@spart}
%%\def\@part[#1]#2{%
%%  \ifnum \c@secnumdepth >\m@ne
%%    \refstepcounter{part}%
%%    \addcontentsline{toc}{part}{%
%%       \prepartname\thepart\postpartname\hspace{1zw}#1}%
%%  \else
%%    \addcontentsline{toc}{part}{#1}%
%%  \fi
%%  \markboth{}{}%
%%  {\parindent\z@\raggedright
%%   \interlinepenalty\@M\reset@font
%%   \ifnum \c@secnumdepth >\m@ne
%%     \Large\bfseries\prepartname\thepart\postpartname
%%     \par\nobreak
%%   \fi
%%   \huge\bfseries#2\par}%
%%  \nobreak\vskip3ex\@afterheading}
%%\def\@spart#1{{%
%%  \parindent\z@\raggedright
%%  \interlinepenalty\@M\reset@font
%%  \huge\bfseries#1\par}%
%%  \nobreak\vskip3ex\@afterheading}

\def\@afterheading{%
 \global\@nobreaktrue
 \everypar{%
  \if@nobreak
   \global\@nobreakfalse
   \clubpenalty \z@
    \if@afterindent
    \else
     {\setbox\z@=\lastbox}%
    \fi
  \else
   \clubpenalty\@clubpenalty
   \everypar{}%
  \fi}%
}

\def\@startsection#1#2#3#4#5#6{%
 \if@noskipsec \leavevmode \fi
 \par \@tempskipa #4\relax
 \@afterindenttrue
 \ifdim \@tempskipa <\z@ \@tempskipa -\@tempskipa \@afterindentfalse\fi
  \if@nobreak
   \everypar{}%
  \else
   %\addpenalty\@secpenalty
     \ifnum#2=\@ne  %% 2(pagetop=1)/*/1 or 1.5(pagetop=0.5)/*/0.5
      \vskip-\prevdepth \prevdepth\z@ \vskip\Cvs
      \advance\@tempskipa-\Cvs
      \advance\@tempskipa-\Cvs
      \vspace{\Cvs}
      \vspace*{\@tempskipa}
     \else
      \ifnum#2=\tw@  %% 1/*/1 or 0.5/*/0.5
       \vskip-\prevdepth \prevdepth\z@ \vskip\Cvs
       \advance\@tempskipa-\Cvs
       \vspace*{\@tempskipa}
      \else
       \ifnum#2=\thr@@ %% 1(pagetop=0)/*/0 same as 1st case
        \vskip-\prevdepth \prevdepth\z@ \vskip\Cvs
        \advance\@tempskipa-\Cvs
        \advance\@tempskipa-\Cvs
        \vspace{\Cvs}
        \vspace*{\@tempskipa}
       \else
        \ifnum#2=4\relax
         \addvspace\@tempskipa
        \else %% subpara -> ??
         \vskip-\prevdepth \prevdepth\z@ \vskip\Cvs
         \advance\@tempskipa-\Cvs
         \vspace*{\@tempskipa}
        \fi
       \fi
      \fi
     \fi
  \fi
 \@ifstar{\@ssect{#3}{#4}{#5}{#6}}{\@dblarg{\@sect{#1}{#2}{#3}{#4}{#5}{#6}}}}

%% \@sect{NAME}{LEVEL}{INDENT}{BEFORESKIP}{AFTERSKIP}{STYLE}[ARG1]{ARG2}
%% \ifdim \@tempskipa>\z@ --> \ifdim \@tempskipa<\z@
\def\@sect#1#2#3#4#5#6[#7]#8{%
 \ifnum #2>\c@secnumdepth
  \let\@svsec\@empty
 \else
  \refstepcounter{#1}%
  \protected@edef\@svsec{\@seccntformat{#1}\relax}%
 \fi
  \@tempskipa #5\relax
  \ifdim \@tempskipa<\z@
   \def\@svsechd{%
     #6{\hskip #3\relax
     \@svsec \sec@format{#2}{#8}}%
   }%
  \else
   \begingroup
    #6{%
     \@hangfrom{\hskip #3\relax{\secnum@font \@svsec}}% para ̂Ƃ?
      \interlinepenalty\@M\sec@format{#2}{#8}\@@par
      }%
   \endgroup
  \fi
  \@xsect{#5}%
}

\newif\ifjidori \jidoritrue %%!! type uRgv̂Ƃ ǂ肵Ȃ
\def\sec@format#1#2{%
 \ifjidori
  \setbox\@tempboxa\hbox{\inhibitglue #2\inhibitglue}%
  \ifnum#1=\@ne %% 5ǂ
   \ifdim\wd\@tempboxa<5.5zw
    \kintou{5zw}{\inhibitglue #2\inhibitglue}%
   \else
    \inhibitglue #2\inhibitglue
   \fi
  \else         %% 3ǂ
   \ifdim\wd\@tempboxa<3.5zw
    \kintou{3zw}{\inhibitglue #2\inhibitglue}%
   \else
    \inhibitglue #2\inhibitglue
   \fi
  \fi
 \else
  \inhibitglue #2\inhibitglue
 \fi
}

%% \@ssect{INDENT}{BEFORESKIP}{AFTERSKIP}{STYLE}{ARG} ==
%% \ifdim \@tempskipa>\z@ --> \ifdim \@tempskipa<\z@
\def\@ssect#1#2#3#4#5{%
  \@tempskipa #3\relax
  \ifdim \@tempskipa<\z@
   \def\@svsechd{#4{\hskip #1\relax\inhibitglue #5\inhibitglue}}% para
  \else
   \begingroup
    #4{%
     \@hangfrom{\hskip #1}%
      \interlinepenalty\@M\ssec@format{#2}{#5}\@@par
      }%
   \endgroup
  \fi
  \@xsect{#3}%
}

\def\ssec@format#1#2{%
 \ifjidori
  \setbox\@tempboxa\hbox{\inhibitglue #2\inhibitglue}%
  \@tempskipa #1\relax
  \ifdim\@tempskipa>\Cvs %% 5ǂ
   \ifdim\wd\@tempboxa<5.5zw
    \kintou{5zw}{\inhibitglue #2\inhibitglue}%
   \else
    \inhibitglue #2\inhibitglue
   \fi
  \else                  %% 3ǂ
   \ifdim\wd\@tempboxa<3.5zw
    \kintou{3zw}{\inhibitglue #2\inhibitglue}%
   \else
    \inhibitglue #2\inhibitglue
   \fi
  \fi
 \else
  \inhibitglue #2\inhibitglue
 \fi
}

%% \ifdim \@tempskipa>\z@ --> \ifdim \@tempskipa<\z@
\def\@xsect#1{%
  \@tempskipa #1\relax
  \ifdim \@tempskipa<\z@
    \@nobreakfalse
    \global\@noskipsectrue
    \everypar{%
      \if@noskipsec
        \global\@noskipsecfalse
       {\setbox\z@\lastbox}%
        \clubpenalty\@M
        \begingroup \@svsechd \endgroup
        \unskip
        \@tempskipa #1\relax
        \hskip -\@tempskipa
        \pagebreak[2]%
      \else
        \clubpenalty \@clubpenalty
        \everypar{}%
      \fi}%
  \else
    \par \nobreak
    \vskip \@tempskipa
    \@afterheading
  \fi
  \ignorespaces}

\def\@seccntformat#1{\csname the#1\endcsname.\hskip1zw}
\def\secnum@font{\sffamily}
\def\sec@font{\bfseries\fontsize{14\@JQ}{\Cvs}\selectfont\mathversion{bold}}
\def\subsec@font{\bfseries\normalsize\mathversion{bold}}
\def\subsubsec@font{\bfseries\small\baselineskip\Cvs\mathversion{bold}}

\newcommand{\section}{% }{
 \@startsection{section}{1}{\z@}%
 {1.4\Cvs \@plus.5\Cdp \@minus.2\Cdp}%
 {0.6\Cvs \@plus.3\Cdp \@minus.2\Cdp}%
 {\reset@font\sec@font}}% \Large\bfseries
\newcommand{\subsection}{% }{
 \@startsection{subsection}{2}{\z@}%
 {.7\Cvs \@plus.5\Cdp \@minus.2\Cdp}%
 {.3\Cvs \@plus.3\Cdp \@minus.2\Cdp}%
 {\reset@font\subsec@font}}% \large\bfseries
\newcommand{\subsubsection}{% }{
 \@startsection{subsubsection}{3}{\z@}%
 {\Cvs \@plus.5\Cdp \@minus.2\Cdp}%
 {\z@ \@plus.3\Cdp \@minus.1\Cdp}%
 {\reset@font\subsubsec@font}}% \normalsize\bfseries
\newcommand{\paragraph}{% }{
 \@startsection{paragraph}{4}{\z@}%
 {.5\Cvs \@plus.3\Cdp \@minus.2\Cdp}%
 {-1zw}%
 {\reset@font\normalsize\bfseries}}
\newcommand{\subparagraph}{% }{
 \@startsection{subparagraph}{5}{\z@}%
 {.5\Cvs \@plus.3\Cdp \@minus.2\Cdp}%
 {-1zw}%
 {\reset@font\normalsize\bfseries}}

\newcommand{\appendix}{\par
 \jidorifalse
 \section*{\appendixname}
 \jidoritrue
 %%
 \setcounter{figure}{0}%
 \setcounter{table}{0}%
 \setcounter{equation}{0}%
 \setcounter{section}{0}%
 \setcounter{subsection}{0}%
 \renewcommand{\thesection}{\@Alph\c@section}%
 \renewcommand{\thesubsection}{\thesection.\the\c@subsection}%
 \renewcommand{\theequation}{\@Alph\c@section.\@arabic\c@equation}%
 \renewcommand{\thefigure}{\@Alph\c@section.\@arabic\c@figure}%
 \renewcommand{\thetable}{\@Alph\c@section.\@arabic\c@table}%
}

\if@twocolumn
 \setlength\leftmargini {2zw}% 2em
\else
 \setlength\leftmargini {2zw}% 2.5em
\fi
\setlength\leftmarginii  {2zw}% 2.2em
\setlength\leftmarginiii {2zw}% 1.87em
\setlength\leftmarginiv  {2zw}% 1.7em
\if@twocolumn
 \setlength\leftmarginv {1zw}% .5em
 \setlength\leftmarginvi{1zw}% .5em
\else
 \setlength\leftmarginv {1zw}% 1em
 \setlength\leftmarginvi{1zw}% 1em
\fi
\setlength  \labelsep  {1zw}% .5em
\setlength  \labelwidth{\leftmargini}
\addtolength\labelwidth{-\labelsep}
\@beginparpenalty \z@ %-\@lowpenalty
\@endparpenalty   \z@ %-\@lowpenalty
\@itempenalty     \z@ %-\@lowpenalty

\renewcommand{\theenumi}{\@arabic\c@enumi}
\renewcommand{\theenumii}{\@alph\c@enumii}
\renewcommand{\theenumiii}{\@roman\c@enumiii}
\renewcommand{\theenumiv}{\@Alph\c@enumiv}
\newcommand{\labelenumi}{\theenumi.}
\newcommand{\labelenumii}{(\theenumii)}
\newcommand{\labelenumiii}{\theenumiii.}
\newcommand{\labelenumiv}{\theenumiv.}
\renewcommand{\p@enumii}{\theenumi}
\renewcommand{\p@enumiii}{\theenumi(\theenumii)}
\renewcommand{\p@enumiv}{\p@enumiii\theenumiii}

\renewenvironment{enumerate}
  {\ifnum \@enumdepth >3\relax\@toodeep\else
   \advance\@enumdepth\@ne
   \edef\@enumctr{enum\romannumeral\the\@enumdepth}%
   \list{\csname label\@enumctr\endcsname}{%
         \ifnum \@listdepth=\@ne \topsep.5\normalbaselineskip
           \else\topsep\z@\fi
         \parskip\z@ \itemsep\z@ \parsep\z@
         \labelwidth1zw \labelsep.5zw
         \ifnum \@enumdepth=\@ne \leftmargin1zw\relax
           \else\leftmargin\leftskip\fi
         \advance\leftmargin 1zw
         \usecounter{\@enumctr}%
         \def\makelabel##1{\hss\llap{##1}}}%
   \fi}{\endlist}

\newcommand{\labelitemi}{\leavevmode
 \if@english\textbullet\else
  \raise.05zh\hbox to 1zw{\hss \textbullet\hss}\fi}
\newcommand{\labelitemii}{\leavevmode
 \if@english $\circ$\else
  \raise.05zh\hbox to 1zw{\hss $\circ$\hss}\fi}
\newcommand{\labelitemiii}{\leavevmode
 \if@english\textasteriskcentered\else
  \raise.05zh\hbox to 1zw{\hss \textasteriskcentered\hss}\fi}
\newcommand{\labelitemiv}{\leavevmode
 \if@english\textperiodcentered\else
  \hbox to 1zw{\hss E\hss}\fi}

\renewenvironment{itemize}
  {\ifnum \@itemdepth >3\relax\@toodeep\else
   \advance\@itemdepth\@ne
   \edef\@itemitem{labelitem\romannumeral\the\@itemdepth}%
   \expandafter
   \list{\csname \@itemitem\endcsname}{%
       \ifnum \@listdepth=\@ne
        \topsep.5\normalbaselineskip
       \else
        \topsep\z@
       \fi
       \parsep\z@\partopsep\z@\itemsep\z@
       \labelwidth1zw
       \labelsep\z@
       \leftmargin1zw
       \def\makelabel##1{\hss\llap{##1}}}%
   \fi}{\endlist}

\newenvironment{description}
  {\list{}{%
%%   \labelwidth\z@ \itemindent-\leftmargin
%%   \iftdir
%%     \leftmargin\leftskip \advance\leftmargin3\Cwd
%%     \rightmargin\rightskip
%%     \labelsep=1zw \itemsep\z@
%%     \listparindent\z@ \topskip\z@ \parskip\z@ \partopsep\z@
%%   \fi
   \leftmargin=1zw
   \labelwidth=\leftmargin
   \labelsep=1zw
   \listparindent1zw
   \advance \labelwidth by -\labelsep
   \itemsep\z@\topsep\z@\parsep\z@\partopsep\z@
   \let\makelabel\descriptionlabel
  }}{\endlist}
\newcommand{\descriptionlabel}[1]{%
%%   \hspace\labelsep\normalfont\bfseries #1
  \setbox0=\hbox{\normalfont\bfseries #1}%
  \dimen0=\wd0  \dimen1=1zw
  \divide \dimen0 by \dimen1
  \multiply \dimen0 by \dimen1
  \ifdim \dimen0<\wd0 \advance \dimen0 by \dimen1 \fi
  \hbox to \dimen0{\box0 \hfil}\hfil
}

\newenvironment{verse}
  {\let\\\@centercr
   \list{}{\itemsep\z@
           \topsep.5\Cvs\parsep\z@\partopsep\z@
           \itemindent -1zw
           \listparindent\itemindent
           \rightmargin\leftmargin \advance\leftmargin 1zw}%
           \item\relax}{\endlist}

\newenvironment{quotation}
  {\list{}{\listparindent 1zw
           \itemindent\listparindent
           \rightmargin\leftmargin
           \topsep.5\Cvs\parsep\z@\partopsep\z@
           }%
           \item\relax}{\endlist}

\newenvironment{quote}
  {\list{}{%
           \topsep.5\Cvs\parsep\z@\partopsep\z@
           \rightmargin\leftmargin}%
           \item\relax}{\endlist}

\gdef\tabbing{\lineskip \z@skip\let\>\@rtab\let\<\@ltab\let\=\@settab
     \let\+\@tabplus\let\-\@tabminus\let\`\@tabrj\let\'\@tablab
     \let\\=\@tabcr
     \@hightab\@firsttab
     \global\@nxttabmar\@firsttab
     \dimen\@firsttab\@totalleftmargin
     \global\@tabpush\z@ \global\@rjfieldfalse
     \topsep.5\Cvs\parsep\z@\partopsep\z@
     \trivlist \item\relax
     \if@minipage\else\vskip\parskip\fi
     \setbox\@tabfbox\hbox{%
       \rlap{\hskip\@totalleftmargin\indent\the\everypar}}%
     \def\@itemfudge{\box\@tabfbox}%
     \@startline\ignorespaces}

\newdimen\verbatimleftmargin
  \verbatimleftmargin\z@
\newdimen\verbatimbaselineskip
  \verbatimbaselineskip\baselineskip
\def\verbatimsize{\normalsize}

\def\@verbatim{%
 \topsep\z@ %.5\Cvs
 \partopsep\z@\parsep\z@\itemsep\z@
 \trivlist \item\relax
  \if@minipage\else
   \vskip\baselineskip
   \vskip-\verbatimbaselineskip
   %\vskip\parskip
  \fi
  \leftskip\@totalleftmargin
  \if@minipage\else
   \advance \leftskip by \verbatimleftmargin
  \fi
  \rightskip\z@skip
  \parindent\z@\parfillskip\@flushglue\parskip\z@skip
  \@@par
  \@tempswafalse
  \def\par{%
    \if@tempswa
      \leavevmode \null \@@par\penalty\interlinepenalty
    \else
      \@tempswatrue
      \ifhmode\@@par\penalty\interlinepenalty\fi
    \fi}%
  \let\do\@makeother \dospecials
  \obeylines 
   \verbatimsize \baselineskip\verbatimbaselineskip
   \verbatim@font\@noligs
  \everypar \expandafter{\the\everypar \unpenalty}%
}
\def\verbatim@font{\normalfont\ttfamily}

%% from latex.ltx
\def\@item[#1]{%
  \if@noparitem
    \@donoparitem
  \else
    \if@inlabel
      \indent \par
    \fi
    \ifhmode
      \unskip\unskip \par
    \fi
    \if@newlist
      \if@nobreak
        \@nbitem
      \else
        \addpenalty\@beginparpenalty
        \addvspace\@topsep
        \addvspace{-\parskip}%
      \fi
    \else
      \addpenalty\@itempenalty
      \addvspace\itemsep
    \fi
    \global\@inlabeltrue
  \fi
  \everypar{%
    \@minipagefalse
    \global\@newlistfalse
    \if@inlabel
      \global\@inlabelfalse
      {\setbox\z@\lastbox
       \ifvoid\z@
         \kern-\itemindent
       \fi}%
      \box\@labels
      \penalty\z@
    \fi
    \if@nobreak
      \@nobreakfalse
      \clubpenalty\z@ % \@M --> \z@ 
    \else
      \clubpenalty \@clubpenalty
      \everypar{\inhibitglue}%
    \fi
  \inhibitglue}%
  \if@noitemarg
    \@noitemargfalse
    \if@nmbrlist
      \refstepcounter\@listctr
    \fi
  \fi
  \sbox\@tempboxa{\makelabel{#1}}%
  \global\setbox\@labels\hbox{%
    \unhbox\@labels
    \hskip \itemindent
    \hskip -\labelwidth
    \hskip -\labelsep
    \ifdim \wd\@tempboxa >\labelwidth
      \box\@tempboxa
    \else
      \hbox to\labelwidth {\unhbox\@tempboxa}%
    \fi
    \hskip \labelsep}%
  \ignorespaces\inhibitglue
}

\newcounter{figure}
\renewcommand{\thefigure}{\@arabic\c@figure}
\def\fps@figure{tbp}
\def\ftype@figure{1}
\def\ext@figure{lof}
\def\fnum@figure{\figurename~\thefigure.}
\newenvironment{figure}
               {\floatenv\capwidth\hsize
                \abovecaptionskip3pt\belowcaptionskip\z@\@float{figure}}
               {\end@float}
\newenvironment{figure*}
               {\floatenv\capwidth\hsize
                \abovecaptionskip3pt\belowcaptionskip\z@\@dblfloat{figure}}
               {\end@dblfloat}
\newcounter{table}
\renewcommand{\thetable}{\@arabic\c@table}
\def\fps@table{tbp}
\def\ftype@table{2}
\def\ext@table{lot}
\def\fnum@table{\tablename~\thetable.}
\newenvironment{table}
               {\floatenv\capwidth\hsize
                \abovecaptionskip\z@\belowcaptionskip3pt\@float{table}}
               {\end@float}
\newenvironment{table*}
               {\floatenv\capwidth\hsize
                \abovecaptionskip\z@\belowcaptionskip3pt\@dblfloat{table}}
               {\end@dblfloat}

\def\@floatboxreset {%
        \reset@font
        \footnotesize\tabcolsep.5zw
        \@setminipage
}

\def\floatenv{\let\center\Center\def\arraystretch{1.3}}

\def\Center{\topsep\z@\partopsep\z@\parsep\z@\itemsep\z@
 \trivlist \centering\item\relax}
\def\endCenter{\endtrivlist}

\long\def\@caption#1[#2]#3{\par
 %\addcontentsline{\csname ext@#1\endcsname}{#1}%
 % {\protect\numberline{\csname the#1\endcsname}{\ignorespaces #2}}%
 \begingroup
  \@parboxrestore
  \if@minipage
   \@setminipage
  \fi
  \footnotesize\baselineskip13H\captionfont
  \@makecaption{\csname fnum@#1\endcsname}{\ignorespaces #3}\par
 \endgroup}

\newdimen\capwidth
\newdimen\abovecaptionskip
\newdimen\belowcaptionskip
\newbox\@tempboxb

\def\captionfont{\footnotesize\bfseries\mathversion{bold}}
\def\capnumfont{\footnotesize\sffamily\gtfamily}

\long\def\@makecaption#1#2{%
 \vskip\abovecaptionskip
 \setbox\@tempboxa\hbox{{\capnumfont #1}\hskip1zw\mbox{}}%
 \setbox\@tempboxb\hbox{\shortstack[l]{\inhibitglue #2\inhibitglue}}%
 \@tempdimb\wd\@tempboxb
 \@tempdima\wd\@tempboxa
 \ifdim \@tempdimb=\z@
  \hbox to \hsize{\capnumfont\hss #1\hss}\par
 \else
  \advance\@tempdima \@tempdimb % <
   \ifdim \@tempdima > \capwidth
    \hfil
    \begin{minipage}[t]{\capwidth}%
     \hangindent=\wd\@tempboxa
     \leavevmode\box\@tempboxa\kern0mm\inhibitglue #2\inhibitglue
    \end{minipage}\par
    \hrule height \z@
   \else
    \hbox to\hsize{\hss\box\@tempboxa
     \parbox[t]{\@tempdimb}{\inhibitglue #2\inhibitglue}\hss}\par
     \hrule height \z@
   \fi
 \fi
 \vspace{\belowcaptionskip}%
}

\arraycolsep 5\p@
\tabcolsep .5zw
\arrayrulewidth .12mm
\doublerulesep 2\p@
\tabbingsep \labelsep

\skip\@mpfootins = \skip\footins
\if@english
 \setlength\fboxsep{3\p@}
 \setlength\fboxrule{.4\p@}
\else
 \setlength\fboxsep{.25zw}
 \setlength\fboxrule{.12mm}
\fi

\renewcommand{\theequation}{\@arabic\c@equation}
\def\@eqnnum{{\normalfont \normalcolor (\theequation)\hskip1zw\mbox{}}}

\if@enablejfam
  \if@compatibility\else
    \DeclareSymbolFont{mincho}{\kenc@JYn}{mc}{m}{n}
    \DeclareSymbolFontAlphabet{\mathmc}{mincho}
    \SetSymbolFont{mincho}{bold}{\kenc@JYn}{gt}{m}{n}
    \jfam\symmincho
    \DeclareMathAlphabet{\mathgt}{\kenc@JYn}{gt}{m}{n}
  \fi
  \if@mathrmmc
    \AtBeginDocument{%
    \reDeclareMathAlphabet{\mathrm}{\mathrm}{\mathmc}
    \reDeclareMathAlphabet{\mathbf}{\mathbf}{\mathgt}
  }%
  \fi
\else
  \DeclareRobustCommand{\mathmc}{%
    \@latex@error{Command \noexpand\mathmc invalid with\space
       `disablejfam' class option.}\@eha
  }
  \DeclareRobustCommand{\mathgt}{%
    \@latex@error{Command \noexpand\mathgt invalid with\space
       `disablejfam' class option.}\@eha
  }
\fi

\DeclareOldFontCommand{\mc}{\normalfont\mcfamily}{\mathmc}
\DeclareOldFontCommand{\gt}{\normalfont\gtfamily}{\mathgt}
\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\DeclareOldFontCommand{\sl}{\normalfont\slshape}{\@nomath\sl}
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\@nomath\sc}
\DeclareRobustCommand*{\cal}{\@fontswitch\relax\mathcal}
\DeclareRobustCommand*{\mit}{\@fontswitch\relax\mathnormal}

\newdimen\bibindent
\setlength\bibindent{1.5em}
\newcommand{\newblock}{\hskip .11em\@plus.33em\@minus.07em}

\newenvironment{thebibliography}[1]
 {%
   \onelineskip
   \if@english
    \subsection*{\refname}%
   \else
    \subsection*{\kintou{7zw}{\refname}}%
   \fi
    %\let\bibitem\@gobble
    \def\bibitem##1{\leavevmode\ignorespaces}%
    \footnotesize\baselineskip15H
    \parindent\z@
    \everypar{\hangindent2zw}%
    \sloppy
    \clubpenalty4000
    \@clubpenalty\clubpenalty
    \widowpenalty4000\relax
    \sfcode`\.\@m
 }{\par}

\let\org@footnote\footnote
\def\footnote{\unskip\leavevmode\inhibitglue\penalty\@M\org@footnote}

%\renewcommand{\footnoterule}{%
%  \kern-3\p@
%  \hrule width \columnwidth % .4\columnwidth
%  \kern 2.6\p@}
%% from Vol.33 No.2
\renewcommand{\footnoterule}{%
  \kern-3\p@
  \hrule width 82.5mm % 11Qx30w
  \kern 2.6\p@}

%\@addtoreset{footnote}{page}

\def\@makefnmark{\penalty\@M
 \smash{\hbox{\kern\z@
  \@textsuperscript{\normalfont\tiny\@thefnmark}\kern\z@}}}

\newcommand\@makefntext[1]{%
 \parindent 2zw
 \everypar{\hangindent1zw}%
 \noindent
 \hbox to 1zw{\@makefnmark\hss}#1}

%\def\thefootnote{\fnsymbol{footnote}}
\def\@fnsymbol#1{\ensuremath{\ifcase#1\or *\or \dagger\or \ddagger\or
   \mathchar "278\or \mathchar "27B\or \|\or **\or \dagger\dagger
   \or \ddagger\ddagger \else\@ctrerr\fi}}

%% Z^O eqnarray
\def\eqnarray{%
   \stepcounter{equation}%
   \def\@currentlabel{\p@equation\theequation}%
   \global\@eqnswtrue
   \m@th
   \global\@eqcnt\z@
   \tabskip\@centering
   \let\\\@eqncr
   $$\everycr{}\halign to\displaywidth\bgroup
       \hskip\@centering$\displaystyle\tabskip\z@skip{##}$\@eqnsel
      &\global\@eqcnt\@ne \hfil$\displaystyle{{}##{}}$\hfil
      &\global\@eqcnt\tw@ $\displaystyle{##}$\hfil\tabskip\@centering
      &\global\@eqcnt\thr@@ \hb@xt@\z@\bgroup\hss##\egroup
         \tabskip\z@skip
      \cr}
\def\endeqnarray{%
      \@@eqncr
      \egroup
      \global\advance\c@equation\m@ne
   $$\@ignoretrue
}

\def\@begintheorem#1#2{%
 \labelsep1zw
 \topsep.5\Cvs \@plus .25\Cvs \@minus .15\Cvs
 \parsep\z@\partopsep\z@\itemsep\z@
 \trivlist
   \item[\hskip \labelsep{\bfseries #1\ #2}]}% \itshape
\def\@opargbegintheorem#1#2#3{%
 \labelsep1zw
 \topsep.5\Cvs \@plus .25\Cvs \@minus .15\Cvs
 \parsep\z@\partopsep\z@\itemsep\z@
 \trivlist
   \item[\hskip \labelsep{\bfseries #1\ #2i#3j\inhibitglue}]}% \itshape
\def\@endtheorem{\endtrivlist}

\newif\if \false
\def\{\true}
\def\a{\false}
\def\today{{%
  \iftdir
    \if
      \kansuji\number\year N
      \kansuji\number\month 
      \kansuji\number\day 
    \else \@tempcnta\year
      \advance\@tempcnta-1988 
      \ifnum \@tempcnta =1 \else\kansuji\number\@tempcnta\fi N
      \kansuji\number\month \kansuji\number\day 
    \fi
  \else
    \if
      \number\year\, N\hspace{.5em}\nobreak
      \number\month\, \hspace{.5em}\nobreak
      \number\day\, 
    \else \@tempcnta\year
      \advance\@tempcnta-1988 
      \ifnum \@tempcnta =1 \else\number\@tempcnta\fi
        \, N\hspace{.5em}\nobreak
      \number\month\, \hspace{.5em}\nobreak\number\day\, 
    \fi
  \fi}}

%%\newcommand{\prepartname}{}
%%\newcommand{\postpartname}{}
%%\newcommand{\contentsname}{ }
%%\newcommand{\listfigurename}{}  }
%%\newcommand{\listtablename}{\  }
%%\newcommand{\indexname}{ }
\if@english
 \newcommand{\refname}{References}
 \newcommand{\figurename}{Figure}
 \newcommand{\tablename}{Table}
 \newcommand{\appendixname}{Appendix}
\else
 \newcommand{\refname}{Ql}
 \newcommand{\figurename}{}}
 \newcommand{\tablename}{\}
 \newcommand{\appendixname}{t\hskip2zw ^}
\fi
%%\newcommand{\abstractname}{T v}

\def\acknowledgment{%
 \if@english
  \onelineskip
  \noindent
  {\bfseries Acknowledgment}\par
 \else
  \onelineskip
  \noindent
  {\bfseries \hskip1zw }\hskip1zw
 \fi
}
\def\endacknowledgment{\par}

\def\received#1#2#3{%
 %% J
 \gdef\j@received{#1N#2#3t}%
 \gdef\rec@YY{#1}%
 %% E
 \def\@temp@m{#2}\ifx\@temp@m\empty\def\@temp@m{0}\fi
 \def\rec@month{%
  \ifcase\@temp@m xxx\or January\or February\or March\or April\or 
   May\or June\or July\or August\or September\or October\or 
   November\or December\fi}%
 \gdef\e@received{Received \rec@month\space #3, #1}%
}
\def\revised#1#2#3{%
 %% J
 \gdef\j@revised{\hskip1zw
  \ifnum\rec@YY=#1\relax\else #1N\fi
   #2#3ŏIC}%
 \gdef\rev@YY{#1}%
 %% E
 \def\rev@month{\def\@temp@m{#2}\ifx\@temp@m\empty\def\@temp@m{0}\fi
  \ifcase\@temp@m xxx\or January\or February\or March\or April\or 
   May\or June\or July\or August\or September\or October\or 
   November\or December\fi}%
 \gdef\e@revised{Received in final form \rev@month\space #3, #1}%
}
\def\accepted#1#2#3{%
 %% J
 \gdef\j@accepted{\hskip1zw
  \ifnum\rev@YY=\z@ % 0 ̂Ƃ(revisedȂ̂Ƃ) received ̔NƔr
   \ifnum\rec@YY=#1\relax\else #1N\fi
  \else
   \ifnum\rev@YY=#1\relax\else #1N\fi
  \fi
   #2#3̑}%
 %% E
 \def\acc@month{\def\@temp@m{#2}\ifx \@temp@m\empty\def\@temp@m{0}\fi
  \ifcase\@temp@m xxx\or January\or February\or March\or April\or 
   May\or June\or July\or August\or September\or October\or 
   November\or December\fi}%
 \gdef\e@accepted{Accepted \acc@month\space #3, #1}%
}

\def\output@Jrefereed{\par
 \ifx \j@received\empty
 \else
  \onelineskip
  \noindent\hfill
  {\footnotesize
   \leavevmode
   \inhibitglue i\j@received\j@revised\j@accepted j\inhibitglue}\par
 \fi
 \let\j@received\relax
 \let\j@revised\relax
 \let\j@accepted\relax
}

\def\output@Erefereed{%
 \vskip\Cvs
 {\small
  \parindent\z@
  %\raggedleft
  \ifx\e@received\empty\let\after@rec\relax\else
   \e@received\fi
  \ifx\e@revised\empty\else
   \after@rec
   \e@revised\fi
  \ifx\e@accepted\empty.\else
   \after@rev
   \e@accepted.\fi
  \par
 }%
 \let\e@received\relax
 \let\e@revised\relax
 \let\e@accepted\relax
}%

\def\j@received{}
\def\j@revised{}
\def\j@accepted{}
\def\rec@YY{0}
\def\rev@YY{0}
\let\refereed\output@Jrefereed

\def\e@received{}
\def\e@revised{}
\def\e@accepted{}
\def\after@rec{;\ }%
\def\after@rev{;\ }%

\def\CorrespondingAuthor#1{\par
 \onelineskip
 \bgroup
  \footnotesize
  \hfill
  ҘA\hbox to 1zw{\hss F\hss}%
  \begin{tabular}[t]{@{}l@{}}
   \@for\@getinfo:=#1\do{%
    \ignorespaces\@getinfo\\
   }%
   \\[-4mm]
  \end{tabular}\par
  \vskip\Cvs
 \egroup
}

\def\E@CorrespondingAuthor#1{\par
 \bgroup
  \parindent\z@
  \ifnum\total@nr=\@ne\else
   \if@p@Eae $^{\ast}$\fi
   Corresponding author\par
  \fi
  %%
  \@tempcnta\z@
  \@for\@getinfo:=#1\do{%
   \advance \@tempcnta \@ne
  }%
  \ifnum\@tempcnta>\@ne
   E-mail addresses:\ 
  \else
   E-mail address:\ 
  \fi
  \begin{tabular}[t]{@{}l@{}}
   \@for\@getinfo:=#1\do{%
    \ignorespaces\@getinfo\\
   }%
   \\[-4mm]
  \end{tabular}\par
 \egroup
}

%% <small macros>
\def\onelineskip{\par\vspace{1\baselineskip}\par}
\def\halflineskip{\par\vspace{.5\baselineskip}\par}
\DeclareRobustCommand\RN[1]{\uppercase\expandafter{\romannumeral#1}}
\DeclareRobustCommand\ddash{\penalty10000\leavevmode
 \if@english\else\raise.15zw\fi\hbox to 2zw{\,---\hss ---\,}}
\def\SA{\leavevmode
 \if@english\else\raise.05zh\fi\hbox to 1zw{\hss $\bullet$\hss}}
\DeclareRobustCommand\kintou[2]{%
 \leavevmode\hbox to #1{%
  \kanjiskip=0pt plus 1fill minus 1fill\xkanjiskip=\kanjiskip#2\hfil}}
\def\ruby@font{%\tiny
 \setbox0\hbox{}%
 \fontsize{.5\wd0}{\z@}\selectfont}
\DeclareRobustCommand\ruby[2]{\leavevmode
 \setbox0=\hbox{#1}\setbox1=\hbox{\ruby@font #2}%
 \ifdim\wd0>\wd1 \dimen0=\wd0 \else \dimen0=\wd1 \fi
 \hbox{\kanjiskip=\fill
  \vbox{\hbox to \dimen0{\ruby@font\hfil#2\hfil}%
  \nointerlineskip \hbox to \dimen0{\hfil#1\hfil}}}}
\def\QED{{\unskip\nobreak\hfil\penalty50
 \hskip1zw\hbox{}\nobreak\hfil \hbox{$\Box$\hskip1zw}
 \parfillskip\z@ \finalhyphendemerits\z@\par}}
\DeclareRobustCommand\MARU[1]{\raisebox{0.1zh}%
 {{\normalfont\ooalign{\hfil\lower.168ex\hbox{#1}\hfil\crcr\mathhexbox20D}}}}
%% </small macros>

\xspcode`+=3
\xspcode`\%=3
\xspcode`^^80=3
\xspcode`^^81=3
\xspcode`^^82=3
\xspcode`^^83=3
\xspcode`^^84=3
\xspcode`^^85=3
\xspcode`^^86=3
\xspcode`^^87=3
\xspcode`^^88=3
\xspcode`^^89=3
\xspcode`^^8a=3
\xspcode`^^8b=3
\xspcode`^^8c=3
\xspcode`^^8d=3
\xspcode`^^8e=3
\xspcode`^^8f=3
\xspcode`^^90=3
\xspcode`^^91=3
\xspcode`^^92=3
\xspcode`^^93=3
\xspcode`^^94=3
\xspcode`^^95=3
\xspcode`^^96=3
\xspcode`^^97=3
\xspcode`^^98=3
\xspcode`^^99=3
\xspcode`^^9a=3
\xspcode`^^9b=3
\xspcode`^^9c=3
\xspcode`^^9d=3
\xspcode`^^9e=3
\xspcode`^^9f=3
\xspcode`^^a0=3
\xspcode`^^a1=3
\xspcode`^^a2=3
\xspcode`^^a3=3
\xspcode`^^a4=3
\xspcode`^^a5=3
\xspcode`^^a6=3
\xspcode`^^a7=3
\xspcode`^^a8=3
\xspcode`^^a9=3
\xspcode`^^aa=3
\xspcode`^^ab=3
\xspcode`^^ac=3
\xspcode`^^ad=3
\xspcode`^^ae=3
\xspcode`^^af=3
\xspcode`^^b0=3
\xspcode`^^b1=3
\xspcode`^^b2=3
\xspcode`^^b3=3
\xspcode`^^b4=3
\xspcode`^^b5=3
\xspcode`^^b6=3
\xspcode`^^b7=3
\xspcode`^^b8=3
\xspcode`^^b9=3
\xspcode`^^ba=3
\xspcode`^^bb=3
\xspcode`^^bc=3
\xspcode`^^bd=3
\xspcode`^^be=3
\xspcode`^^bf=3
\xspcode`^^c0=3
\xspcode`^^c1=3
\xspcode`^^c2=3
\xspcode`^^c3=3
\xspcode`^^c4=3
\xspcode`^^c5=3
\xspcode`^^c6=3
\xspcode`^^c7=3
\xspcode`^^c8=3
\xspcode`^^c9=3
\xspcode`^^ca=3
\xspcode`^^cb=3
\xspcode`^^cc=3
\xspcode`^^cd=3
\xspcode`^^ce=3
\xspcode`^^cf=3
\xspcode`^^d0=3
\xspcode`^^d1=3
\xspcode`^^d2=3
\xspcode`^^d3=3
\xspcode`^^d4=3
\xspcode`^^d5=3
\xspcode`^^d6=3
\xspcode`^^d7=3
\xspcode`^^d8=3
\xspcode`^^d9=3
\xspcode`^^da=3
\xspcode`^^db=3
\xspcode`^^dc=3
\xspcode`^^dd=3
\xspcode`^^de=3
\xspcode`^^df=3
\xspcode`^^e0=3
\xspcode`^^e1=3
\xspcode`^^e2=3
\xspcode`^^e3=3
\xspcode`^^e4=3
\xspcode`^^e5=3
\xspcode`^^e6=3
\xspcode`^^e7=3
\xspcode`^^e8=3
\xspcode`^^e9=3
\xspcode`^^ea=3
\xspcode`^^eb=3
\xspcode`^^ec=3
\xspcode`^^ed=3
\xspcode`^^ee=3
\xspcode`^^ef=3
\xspcode`^^f0=3
\xspcode`^^f1=3
\xspcode`^^f2=3
\xspcode`^^f3=3
\xspcode`^^f4=3
\xspcode`^^f5=3
\xspcode`^^f6=3
\xspcode`^^f7=3
\xspcode`^^f8=3
\xspcode`^^f9=3
\xspcode`^^fa=3
\xspcode`^^fb=3
\xspcode`^^fc=3
\xspcode`^^fd=3
\xspcode`^^fe=3
\xspcode`^^ff=3

\postbreakpenalty`i=10000
\prebreakpenalty`j=10000
\postbreakpenalty`m=10000
\prebreakpenalty`n=10000
\postbreakpenalty`q=10000
\prebreakpenalty`r=10000
\prebreakpenalty`"=10000 % "
\prebreakpenalty`=10000
\prebreakpenalty`@=10000
\prebreakpenalty`E=10000
\prebreakpenalty`&#12316;=10000
\prebreakpenalty`[=10000
\prebreakpenalty`H=10000
\prebreakpenalty`I=10000
\if@enable@uptex
\postbreakpenalty16=10000
\else
\postbreakpenalty"5C=10000 % "
\fi
\postbreakpenalty`y=10000
\prebreakpenalty`z=10000
\postbreakpenalty`k=10000
\prebreakpenalty`l=10000
\postbreakpenalty`w=10000
\prebreakpenalty`x=10000
\inhibitxspcode`=2
\inhibitxspcode`I=1

\def\sloppy{\tolerance9999\hbadness9999\hfuzz.5\p@ \vfuzz.5\p@}

\hbadness4000
%\vbadness10001
\tolerance4000\pretolerance\m@ne
\clubpenalty\z@
\widowpenalty\z@

\AtBeginDocument{%
 \label{jjas@first@page}%
 %%
 \displaywidowpenalty\z@
 \interdisplaylinepenalty\z@ % 100 
 \predisplaypenalty\z@       % 1000
 \postdisplaypenalty\z@      % 1000
 %% cmex
 \@ifundefined{cmex@opt}{%
  \DeclareFontFamily{OMX}{cmex}{}{}%
  \DeclareFontShape{OMX}{cmex}{m}{n}{%
   <->    cmex10
  }{}%
 }{%
  \ifnum\cmex@opt=7\relax
   \DeclareFontFamily{OMX}{cmex}{}{}%
   \DeclareFontShape{OMX}{cmex}{m}{n}{%
    <->    cmex10
   }{}%
  \fi
 }%
 %% amsmath
 \@ifpackageloaded{amsmath}{%
  \def\maketag@@@#1{\hbox{\m@th\normalfont #1}\hskip1zw}%
  \def\eqref#1{\textup{\tagform@{\ref{#1}}\unskip}}%
 }{}%
 %% amsthm.sty
 \@ifpackageloaded{amsthm}{%
  %% \thm@preskip=\topsep \thm@postskip=\thm@preskip ƒ`ς
  %% [] ̒̃p[Sp/̃s폜/head ̌ꎚ󂫂
  \def\@thm#1#2#3{%
    \ifhmode\unskip\unskip\par\fi
    \normalfont
    \trivlist
    \let\thmheadnl\relax
    \let\thm@swap\@gobble
    %\thm@notefont{\fontseries\mddefault\upshape}%
    \thm@notefont{\bfseries}%
    %\thm@headpunct{.}% add period after heading
    \thm@headpunct{}% add period after heading
    %\thm@headsep 5\p@ plus\p@ minus\p@\relax
    \thm@headsep 1zw \@plus .15zw \@minus .25zw\relax
    \thm@space@setup
    #1% style overrides
    \@topsep \thm@preskip               % used by thm head
    \@topsepadd \thm@postskip           % used by \@endparenv
    \def\@tempa{#2}\ifx\@empty\@tempa
      \def\@tempa{\@oparg{\@begintheorem{#3}{}}[]}%
    \else
      \refstepcounter{#2}%
      \def\@tempa{\@oparg{\@begintheorem{#3}{\csname the#2\endcsname}}[]}%
    \fi
    \@tempa
  }%
  %\def\@endtheorem{\endtrivlist \@doendpe}% \@endpefalse void
  \def\th@plain{% style=plain
   %\itshape % body font
  }%
  \def\th@remark{% style=remark
   \thm@headfont{\bfseries}%
   \normalfont % body font
   %\thm@preskip\topsep \divide\thm@preskip\tw@
   %\thm@postskip\thm@preskip
  }%
  %% pp[Sp
  \def\thmhead@plain#1#2#3{%
    \thmname{#1}\thmnumber{\@ifnotempty{#1}{ }\@upn{#2}}%
    \thmnote{{\the\thm@notefont i#3j\inhibitglue}}}%
  \let\thmhead\thmhead@plain
  %% \swapnumbers WJꂽƂL
  \def\swappedhead#1#2#3{%
    \thmnumber{#2}%
    \thmname{\@ifnotempty{#2}{~}#1}%
    \thmnote{ {\the\thm@notefont i#3j\inhibitglue}}}%
  %% proof
  \def\proofname{\textbf{ؖ}}%
  \renewenvironment{proof}[1][\proofname]{\par
    \pushQED{\qed}%
    \normalfont
    %\topsep6\p@\@plus6\p@\relax
    \labelsep1zw
    \topsep.5\Cvs \@plus .25\Cvs \@minus .15\Cvs
    \trivlist
    \item[\hskip\labelsep
          %\itshape 
      \textbf{#1\inhibitglue}\@addpunct{}]\ignorespaces
  }{%
    \popQED\endtrivlist\@endpefalse
  }%
 }{}%
 %% theorem.sty
 \@ifpackageloaded{theorem}{%
  \theoremstyle{plain}%
  \theorembodyfont{\normalfont}%
  \theoremheaderfont{\bfseries}
  %\def\theorem@headerfont{\bfseries}%
  \global\setlength\theorempreskipamount{%
   .5\Cvs \@plus .25\Cvs \@minus .15\Cvs}%
  \global\setlength\theorempostskipamount{%
   .5\Cvs \@plus .25\Cvs \@minus .15\Cvs}%
  \gdef\th@plain{\normalfont %\itshape
   \def\@begintheorem##1##2{%
    \item[\hskip\labelsep \theorem@headerfont ##1\ ##2]}%
   \def\@opargbegintheorem##1##2##3{%
    \item[\hskip\labelsep{\theorem@headerfont ##1\ ##2i##3j\inhibitglue}]}%
  }%
  %% \theoremstyle{break}
  \gdef\th@break{\normalfont %\slshape
   \def\@begintheorem##1##2{%
    \labelsep1zw %\@plus .15zw \@minus .25zw
    \item[\rlap{\vbox{\hbox{\hskip \labelsep
     \theorem@headerfont ##1\ ##2}%
     \hbox{\strut}}}]}%
   \def\@opargbegintheorem##1##2##3{%
    \labelsep1zw %\@plus .15zw \@minus .25zw
    \item[\rlap{\vbox{\hbox{\hskip \labelsep
     \theorem@headerfont ##1\ ##2i##3j\inhibitglue}%
     \hbox{\strut}}}]}}%
 }{}%
 %% natbib.sty
 %%\def\NAT@@citetp[#1]{\@ifnextchar[{\@citex[#1]}{\@citex[][#1]}}% ]
 \@ifpackageloaded{natbib}{% version 8.31b
  \renewcommand\NAT@open{i}% \inhibitglue
  \renewcommand\NAT@close{j}% \inhibitglue
  \def\citeP{\begingroup
     \renewcommand\NAT@open{i}%
     \renewcommand\NAT@close{j}%
     \renewcommand\NAT@cmt{}%
     \NAT@swatrue\let\NAT@ctype\z@\NAT@partrue
     \@ifstar{\NAT@fulltrue\NAT@citetp}{\NAT@fullfalse\NAT@citetp}}%
  %%
  \@ifundefined{setcitestyle}{}{\setcitestyle{yysep={,~}}}% for v7.1 etc.
  \def\bibsection{%
   \onelineskip
   \if@english
    \subsection*{\refname}%
   \else
    \subsection*{\kintou{7zw}{\refname}}%
   \fi
  }%
  \def\bibfont{\footnotesize\baselineskip15H}%
  %\def\bibpostamble{}%
  \bibhang2zw
  \bibsep0pt
 }{}%
 %% enumerate.sty
 \@ifpackageloaded{enumerate}{%
  \def\@@enum@[#1]{%
    \@enLab{}\let\@enThe\@enQmark
    \@enloop#1\@enum@
    \ifx\@enThe\@enQmark\@warning{The counter will not be printed.%
     ^^J\space\@spaces\@spaces\@spaces The label is: \the\@enLab}\fi
    \expandafter\edef\csname label\@enumctr\endcsname{\the\@enLab}%
    \expandafter\let\csname the\@enumctr\endcsname\@enThe
    \csname c@\@enumctr\endcsname7
    \expandafter\settowidth
              \csname leftmargin\romannumeral\@enumdepth\endcsname
              {\the\@enLab\hspace{\labelsep}}% 
    \@enum@}%
  \def\@enum@{%
   \list{\csname label\@enumctr\endcsname}%
    {\labelsep.5zw
     \expandafter\leftmargin\csname leftmargin\romannumeral\@enumdepth\endcsname
     \itemindent\z@
     \ifnum \@listdepth=\@ne
      \topsep.5\baselineskip
     \else
      \topsep\z@
     \fi
     \parsep\z@\partopsep\z@\itemsep\z@
     %%
     \usecounter{\@enumctr}\def\makelabel##1{\hss\llap{##1}}}%
  }%
 }{}%
 %% float.sty
 \@ifpackageloaded{float}{%
   \renewcommand\float@endH{\@endfloatbox
     \vskip\intextsep
     \if@flstyle\setbox\@currbox\float@makebox\columnwidth\fi
     \box\@currbox
     \vskip-.5zh %% added
     \vskip\intextsep\relax}%
 }{}%
}

\newif\if@addwhitepage \@addwhitepagefalse
\def\addwhitepage{%
 %\label{jjas@last@page}%
 \clearpage
 \addtocounter{page}{-1}%
 \immediate\write\@auxout{\string
  \newlabel{jjas@last@page}{{}{\thepage}}}%
 \addtocounter{page}{1}%
 \clearpage
 \thispagestyle{empty}
 \mbox{}\par
 \global\@addwhitepagetrue
}

\AtEndDocument{%
 \if@addwhitepage\else
  %\label{jjas@last@page}%
  \clearpage
  \addtocounter{page}{-1}%
  \immediate\write\@auxout{\string
   \newlabel{jjas@last@page}{{}{\thepage}}}%
  \addtocounter{page}{1}%
 \fi
}

\pagestyle{bothstyle}
\pagenumbering{arabic}
\raggedbottom
\if@twocolumn
 \twocolumn
 %\sloppy
 \flushbottom
\else
 \onecolumn
\fi
\if@twoside
 \@mparswitchtrue
\else
 \@mparswitchfalse
\fi

\endinput
